#
# spec file for package python3-networkx
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-networkx
Version:        1.11
Release:        1.6
Summary:        Python package for the creation, manipulation,
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            http://networkx.lanl.gov
Source:         https://files.pythonhosted.org/packages/source/n/networkx/networkx-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python3-PyYAML
BuildRequires:  python3-decorator >= 3.4.0
BuildRequires:  python3-devel
BuildRequires:  python3-matplotlib
BuildRequires:  python3-numpy-devel
BuildRequires:  python3-pyparsing
BuildRequires:  python3-scipy
BuildRequires:  python3-setuptools
Requires:       python3-decorator >= 3.4.0
Recommends:     python3-matplotlib
Recommends:     python3-numpy
Recommends:     python3-PyYAML
Recommends:     python3-pyparsing
Recommends:     python3-scipy
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
NetworkX (NX) is a Python package for the creation, manipulation, and study of the structure, dynamics,
and functions of complex networks.

Features:
 * Includes standard graph-theoretic and statistical physics functions
 * Easy exchange of network algorithms between applications, disciplines, and platforms
 * Includes many classic graphs and synthetic networks
 * Nodes and edges can be "anything" (e.g. time-series, text, images, XML records)
 * Exploits existing code from high-quality legacy software in C, C++, Fortran, etc.
 * Open source (encourages community input)
 * Unit-tested

%prep
%setup -q -n networkx-%{version}
sed -i -e "s@share/doc/networkx-.*@share/doc/packages/%{name}'@g" setup.py
find networkx/ examples/ -name "*.py" -exec sed -i -e  '/^#!\s\?\/usr\/bin\/\(env\s\)\?python$/d' {} ';'
sed -i 's/\r//' examples/algorithms/hartford_drug.edgelist

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root %{buildroot}
rm -r %{buildroot}%{_docdir}/%{name}/INSTALL.txt # Makes no sense
%fdupes -s %{buildroot}

%files
%defattr(-,root,root)
%{_docdir}/%{name}
%{python3_sitelib}/networkx/
%{python3_sitelib}/networkx-%{version}-py*.egg-info

%changelog
* Sun May  8 2016 arun@gmx.de
- specfile:
  * changed to https for source url
  * updated source url to files.pythonhosted.org
* Sun Jan 31 2016 arun@gmx.de
- specfile:
  * update copyright year
- update to version 1.11:
  * Release for fixes of installation on some machines, layouts and
    docs.
* Mon Aug 10 2015 arun@gmx.de
- update to version 1.10:
  * long list of changes, see http://networkx.readthedocs.org/en/stable/reference/api_1.10.html
* Thu Feb 26 2015 toddrme2178@gmail.com
- Fix python3-decorator dependency syntax
* Fri Jan  9 2015 arun@gmx.de
- specfile:
  * added dependency to python3-decorator
* Mon Jan  5 2015 arun@gmx.de
- specfile:
  * update copyright year
  * add setuptools
- update to version 1.9.1:
  * Completely rewritten maximum flow and flow-based connectivity
    algorithms with backwards incompatible interfaces
  * Community graph generators
  * Stoer–Wagner minimum cut algorithm
  * Linear-time Eulerian circuit algorithm
  * Linear algebra package changed to use SciPy sparse matrices
  * Algebraic connectivity, Fiedler vector, spectral ordering algorithms
  * Link prediction algorithms
  * Goldberg–Radzik shortest path algorithm
  * Semiconnected graph and tree recognition algorithms
  * API changes See Version 1.9 notes and API changes.
    http://networkx.github.io/documentation/networkx-1.9.1/reference/api_1.9.html
* Fri Dec  6 2013 toddrme2178@gmail.com
- Update to 1.8.1
  * Bugfixes
- Update to 1.8
  * Faster (linear-time) graphicality tests and Havel-Hakimi
    graph generators
  * Directed Laplacian matrix generator
  * Katz centrality algorithm
  * Functions to generate all simple paths
  * Improved shapefile reader
  * More flexible weighted projection of bipartite graphs
  * Faster topological sort, decendents and ancestors of DAGs
  * Scaling parameter for force-directed layout
- Update to 1.7
  * New functions for k-clique community finding, flow hierarchy,
    union, disjoint union, compose, and intersection operators that
    work on lists of graphs, and creating the biadjacency matrix of
    a bipartite graph.
  * New approximation algorithms for dominating set, edge dominating
    set, independent set, max clique, and min-weighted vertex cover.
  * Many bug fixes and other improvements.
- Add optional dependencies as Recommends
- Add python 3 version
* Tue Jan 31 2012 saschpe@suse.de
- Don't package INSTALL.txt and other docs twice
* Thu Jan 12 2012 saschpe@suse.de
- Spec file cosmetics
* Wed Jan 11 2012 toddrme2178@gmail.com
- Cleaned up spec file
- Renamed package from python-NetworkX to python-networkx to match the module name
* Thu Sep  8 2011 alinm.elena@gmail.com
- initial commit
* Fri Feb  6 2009 urs.beyerle@env.ethz.ch
- update to 0.99
* Thu Jun 26 2008 ti.eugene@gmail.com
- Initial build
